==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythweb/modules/stats/handler.php <==
<?php
/**
 * Mythweb recording stats.
 *
 * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/modules/stats/handler.php $
 * @date        $Date: 2006-04-06 22:53:45 -0400 (Thu, 06 Apr 2006) $
 * @version     $Revision: 9639 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  Stats
 *
 * UPDATE oldrecorded, program
 *    SET oldrecorded.endtime=FROM_UNIXTIME(UNIX_TIMESTAMP(oldrecorded.starttime)
 *                                          +(UNIX_TIMESTAMP(program.endtime)
 *                                            -UNIX_TIMESTAMP(program.starttime)))
 *  WHERE oldrecorded.title=program.title
 *        AND oldrecorded.recstatus = -3
 *        AND oldrecorded.endtime <= oldrecorded.starttime
 *        AND program.endtime > program.starttime;
 *
/**/
    $where = ' WHERE 1';
    if ($_REQUEST['query_time'] == 'day')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-24*60*60);
    if ($_REQUEST['query_time'] == 'week')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-7*24*60*60);
    if ($_REQUEST['query_time'] == 'month')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-31*24*60*60);
    if ($_REQUEST['query_time'] == 'year')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-365*24*60*60);
    $where .= ' AND oldrecorded.recstatus = -3';

    $limit = 'LIMIT 10';
    if($_REQUEST['count_dropdown'] == 25)
    	$limit = 'LIMIT 25';
    if($_REQUEST['count_dropdown'] == 50)
    	$limit = 'LIMIT 50';
    if($_REQUEST['count_dropdown'] == 100)
        $limit = 'LIMIT 100';
    if($_REQUEST['count_dropdown'] == 'all')
    	$limit = '';


// Get how many show titles their are
    $sh = $db->query('SELECT DISTINCT title FROM oldrecorded'.$where);
    $title_count = $sh->num_rows();
    $sh->finish();

// Get how many shows ever recorded
    $show_count = $db->query_col('SELECT COUNT(title)
                                    FROM oldrecorded '.$where);

// Get the time of the first recording
    $first = $db->query_col('SELECT UNIX_TIMESTAMP(starttime)
                               FROM oldrecorded '.$where
                        .' ORDER BY starttime ASC LIMIT 1');

// Get the time of the last recording
    $last = $db->query_col('SELECT UNIX_TIMESTAMP(endtime)
                              FROM oldrecorded '.$where
                       .' ORDER BY endtime DESC LIMIT 1');

// Get the total time of the recorded shows
    $time = $db->query_col('SELECT SUM(UNIX_TIMESTAMP(endtime) - UNIX_TIMESTAMP(starttime))
                              FROM oldrecorded '
                         .$where.' AND endtime > starttime');

// Get the top ten recorded shows
    $sh = $db->query('SELECT title, COUNT(programid) AS count, MAX(UNIX_TIMESTAMP(starttime)) AS last_recorded
                        FROM oldrecorded '.$where
                 .' GROUP BY title
                    ORDER BY count DESC, last_recorded, title '
                    .$limit);
    while($row = $sh->fetch_assoc())
        $top_ten_shows[] = $row;
    $sh->finish();

// Get the top ten recorded shows
    $sh = $db->query('SELECT COUNT(oldrecorded.chanid) as count,
                             channel.name,
                             channel.channum,
                             MAX(UNIX_TIMESTAMP(oldrecorded.starttime)) as last_recorded
                        FROM oldrecorded
                             LEFT JOIN channel
                                    ON channel.chanid = oldrecorded.chanid
                    '.$where.'
                             AND channel.channum IS NOT NULL
                    GROUP BY oldrecorded.chanid
                    ORDER BY count DESC, last_recorded, name '
                    .$limit);
    while($row = $sh->fetch_assoc())
        $top_ten_chans[] = $row;
    $sh->finish();

// Print the stats page template
    require_once tmpl_dir.'stats.php';

// Yup, that really is it.
    exit;

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythweb/modules/stats/handler.php <==
<?php
/**
 * Mythweb recording stats.
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/stats/handler.php $
 * @date        $Date: 2006-04-06 21:53:45 -0500 (Thu, 06 Apr 2006) $
 * @version     $Revision: 9639 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  Stats
 *
 * UPDATE oldrecorded, program
 *    SET oldrecorded.endtime=FROM_UNIXTIME(UNIX_TIMESTAMP(oldrecorded.starttime)
 *                                          +(UNIX_TIMESTAMP(program.endtime)
 *                                            -UNIX_TIMESTAMP(program.starttime)))
 *  WHERE oldrecorded.title=program.title
 *        AND oldrecorded.recstatus = -3
 *        AND oldrecorded.endtime <= oldrecorded.starttime
 *        AND program.endtime > program.starttime;
 *
/**/
    $where = ' WHERE 1';
    if ($_REQUEST['query_time'] == 'day')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-24*60*60);
    if ($_REQUEST['query_time'] == 'week')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-7*24*60*60);
    if ($_REQUEST['query_time'] == 'month')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-31*24*60*60);
    if ($_REQUEST['query_time'] == 'year')
        $where = ' WHERE UNIX_TIMESTAMP(starttime) > '.(time()-365*24*60*60);
    $where .= ' AND oldrecorded.recstatus = -3';

    $limit = 'LIMIT 10';
    if($_REQUEST['count_dropdown'] == 25)
    	$limit = 'LIMIT 25';
    if($_REQUEST['count_dropdown'] == 50)
    	$limit = 'LIMIT 50';
    if($_REQUEST['count_dropdown'] == 100)
        $limit = 'LIMIT 100';
    if($_REQUEST['count_dropdown'] == 'all')
    	$limit = '';


// Get how many show titles their are
    $sh = $db->query('SELECT DISTINCT title FROM oldrecorded'.$where);
    $title_count = $sh->num_rows();
    $sh->finish();

// Get how many shows ever recorded
    $show_count = $db->query_col('SELECT COUNT(title)
                                    FROM oldrecorded '.$where);

// Get the time of the first recording
    $first = $db->query_col('SELECT UNIX_TIMESTAMP(starttime)
                               FROM oldrecorded '.$where
                        .' ORDER BY starttime ASC LIMIT 1');

// Get the time of the last recording
    $last = $db->query_col('SELECT UNIX_TIMESTAMP(endtime)
                              FROM oldrecorded '.$where
                       .' ORDER BY endtime DESC LIMIT 1');

// Get the total time of the recorded shows
    $time = $db->query_col('SELECT SUM(UNIX_TIMESTAMP(endtime) - UNIX_TIMESTAMP(starttime))
                              FROM oldrecorded '
                         .$where.' AND endtime > starttime');

// Get the top ten recorded shows
    $sh = $db->query('SELECT title, COUNT(programid) AS count, MAX(UNIX_TIMESTAMP(starttime)) AS last_recorded
                        FROM oldrecorded '.$where
                 .' GROUP BY title
                    ORDER BY count DESC, last_recorded, title '
                    .$limit);
    while($row = $sh->fetch_assoc())
        $top_ten_shows[] = $row;
    $sh->finish();

// Get the top ten recorded shows
    $sh = $db->query('SELECT COUNT(oldrecorded.chanid) as count,
                             channel.name,
                             channel.channum,
                             MAX(UNIX_TIMESTAMP(oldrecorded.starttime)) as last_recorded
                        FROM oldrecorded
                             LEFT JOIN channel
                                    ON channel.chanid = oldrecorded.chanid
                    '.$where.'
                             AND channel.channum IS NOT NULL
                    GROUP BY oldrecorded.chanid
                    ORDER BY count DESC, last_recorded, name '
                    .$limit);
    while($row = $sh->fetch_assoc())
        $top_ten_chans[] = $row;
    $sh->finish();

// Print the stats page template
    require_once tmpl_dir.'stats.php';

// Yup, that really is it.
    exit;
